=================
DjangoWechatBase
=================

基于Django的Wechat基础模块, 包括微信开放平台, 微信小程序, 微信公众平台

快速使用
----------

1. 安装django-wechat ::

    $ pip install django-wechat

2. 更新settings.py ::

    WECHAT = {
        'appid': '',
        'secret': '',
        'mch_id': '',
        'key': ''
    }
